#!/bin/bash

source /etc/profile
_gameId="_gameId_"
_dir=$(cd "$(dirname "$0")"; pwd)

# support date param
if [ $# -gt 0 ]; then
    dir_name=$1
else
    dir_name=`date -d "1 hours ago" +%Y-%m-%d`
fi

_HOST=`hostname`
ZONEID=${_HOST##*-}
BI_ADDR="_rsync_ip_"
BI_PORT="_rsync_port_"
BI_USER="_rsync_user_"
BI_MODU="_rsync_module_"
RSYNC_PASS="${_dir}/rsync.pass"
echo "rsync${BI_MODU}123s56.." >${RSYNC_PASS}
chmod 600 $RSYNC_PASS

# decide fileRoot and fileame
if [ -f "_auany_log_root_/_auany_logfile_name_" ];then
   ZONEID="`echo $_HOST | cut -d \- -f2`auany"
   pushd _auany_log_root_  > /dev/null
        DST="${dir_name}_${ZONEID}_${_gameId}.log"
        if [ ${dir_name} == `date  +%Y-%m-%d` ];then
           ln -snf _auany_logfile_name_ ${DST}
        else
           ln -snf _auany_logfile_name_.${dir_name} ${DST}
        fi

        if [ $# -gt 1 ]; then
            _hour=$2
            if [ "${#_hour}" = "1" ]; then
               _hour="0${_hour}"
            fi
        else
            _hour=`date -d "1 hours ago" +%H`
        fi

        file_name=${dir_name}-${_hour}_${ZONEID}_${_gameId}
        awk_cmd="awk --re-interval -F'|' '\$1 ~ /^[0-9]{4}-[0-9]{2}-[0-9]{2} ${_hour}/'"
        grep "${dir_name} ${_hour}:" ${DST} | eval "$awk_cmd" > ${file_name}.log
        [ -f ${file_name}.gz ] || (gzip -c ${file_name}.log > ${file_name}.gz && md5sum ${file_name}.gz > ${file_name}.md5)
        /bin/rm -f ${DST} && /bin/rm -f ${file_name}.log
        _dstfile="${dir_name}-*_${ZONEID}_${_gameId}"
        for i in `seq 1 5`
        do
            rsync -avzc --bwlimit=5000 --port=${BI_PORT} --contimeout=180 --password-file=${RSYNC_PASS} ${_dstfile}.* ${BI_USER}@${BI_ADDR}::${BI_MODU}/$dir_name/ &>>${_dir}/rsync_log.log
            if [ $? = 0 ];then
                break
            else
                sleep  300
            fi
        done

        case ${_hour} in
            00|01|02)
            _yday=`date -d "1 days ago ${dir_name}" +%Y-%m-%d`
            _ydstfile="${_yday}-*_${ZONEID}_${_gameId}"
            _ynum=`ls ${_ydstfile}.md5 2>/dev/null |wc -l`
            if [ "${_ynum}k" != "0k" ]; then
            rsync -avzc --bwlimit=5000 --port=${BI_PORT} --contimeout=180 --password-file=${RSYNC_PASS} ${_ydstfile}.* ${BI_USER}@${BI_ADDR}::${BI_MODU}/${_yday}/ &>>${_dir}/rsync_log.log
            fi
            ;;
            *)
            echo
            ;;
        esac

        _2day=`date -d "2 days ago ${dir_name}" +%Y-%m-%d` && /bin/rm -f ${_2day}*.gz ${_2day}*.md5
   popd  > /dev/null
else
   pushd _game_log_root_/${dir_name}  > /dev/null
        for _file in `ls level2.log.*`
        do
           H=`ls ${_file}|awk -F . '{print $3}'`
           if [ ${H} -lt 10 ];then
              DST0=${dir_name}-0${H}_${ZONEID}_${_gameId}
              DST1=${dir_name}-0${H}-lv1_${ZONEID}_${_gameId}
              DST2=${dir_name}-0${H}-lv2_${ZONEID}_${_gameId}
           else
              DST0=${dir_name}-${H}_${ZONEID}_${_gameId}
              DST1=${dir_name}-${H}-lv1_${ZONEID}_${_gameId}
              DST2=${dir_name}-${H}-lv2_${ZONEID}_${_gameId}
           fi
           /bin/rm -f ${DST1}.log && ln -s level1.log.${H} ${DST1}.log
           /bin/rm -f ${DST2}.log && ln -s level2.log.${H} ${DST2}.log
           [ -f ${DST0}.gz ] || gzip -c ${DST1}.log ${DST2}.log > ${DST0}.gz
           [ -f ${DST0}.md5 ] || md5sum ${DST0}.gz > ${DST0}.md5
	   /bin/rm -f ${DST1}.log ${DST2}.log
       done
       
       DST="${dir_name}-*_${ZONEID}_${_gameId}"
       for i in `seq 1 5`
       do
           rsync -avzc --bwlimit=5000 --port=${BI_PORT} --contimeout=180 --password-file=${RSYNC_PASS} ${DST}.* ${BI_USER}@${BI_ADDR}::${BI_MODU}/${dir_name}/ &>>${_dir}/rsync_log.log
           if [ $? = 0 ];then
               break
           else
               sleep  300
           fi
       done

       case ${_hour} in
           00|01|02)
           _yday=`date -d "1 days ago ${dir_name}" +%Y-%m-%d`
           _ydstfile="${_yday}-*_${ZONEID}_${_gameId}"
           _ynum=`ls _game_log_root_/${_yday}/${_ydstfile}.md5 2>/dev/null |wc -l`
           if [ "${_ynum}k" != "0k" ]; then
           rsync -avzc --bwlimit=5000 --port=${BI_PORT} --contimeout=180 --password-file=${RSYNC_PASS} _game_log_root_/${_yday}/${_ydstfile}.* ${BI_USER}@${BI_ADDR}::${BI_MODU}/${_yday}/ &>>${_dir}/rsync_log.log
           fi
           ;;
           *)
           echo
           ;;
       esac

       /bin/rm -f ${dir_name}-*lv*_${ZONEID}_${_gameId}.log
   popd  > /dev/null
fi
